###############################
Toptica IBeam Smart Laser diode
###############################

.. autoclass:: pymeasure.instruments.toptica.ibeamsmart.IBeamSmart
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.toptica.ibeamsmart.DriverChannel
    :members:
    :show-inheritance:
